==> trade-center-api-0.0.8-20160728.123243-2-sources.jar: cn/com/duiba/order/center/api/dto/CreditsMessage.java <==
package cn.com.duiba.order.center.api.dto;

import java.util.Map;

/**
 * 扣积分消息封装类
 */
public class CreditsMessage {

	public static final String HTTP_GET = "get";
	public static final String HTTP_POST = "post";

	private String relationId;
	private String relationType;
	private String appId;
	private String consumerId;
	private String httpType;
	private String httpUrl;
	private Map<String, String> authParams;
	private Map<String, String> params;
	private Long timestamp;

	public String getRelationId() {
		return relationId;
	}

	public void setRelationId(String relationId) {
		this.relationId = relationId;
	}

	public String getRelationType() {
		return relationType;
	}

	public void setRelationType(String relationType) {
		this.relationType = relationType;
	}

	public String getAppId() {
		return appId;
	}

	public void setAppId(String appId) {
		this.appId = appId;
	}

	public String getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(String consumerId) {
		this.consumerId = consumerId;
	}

	public String getHttpType() {
		return httpType;
	}

	public void setHttpType(String httpType) {
		this.httpType = httpType;
	}

	public String getHttpUrl() {
		return httpUrl;
	}

	public void setHttpUrl(String httpUrl) {
		this.httpUrl = httpUrl;
	}

	public Map<String, String> getParams() {
		return params;
	}

	public void setParams(Map<String, String> params) {
		this.params = params;
	}

	public Map<String, String> getAuthParams() {
		return authParams;
	}

	public void setAuthParams(Map<String, String> authParams) {
		this.authParams = authParams;
	}

	public Long getTimestamp() {
		return timestamp;
	}

	public void setTimestamp(Long timestamp) {
		this.timestamp = timestamp;
	}
	
}

==> trade-center-api-0.1.0-20160803.114630-1-sources.jar: cn/com/duiba/order/center/api/dto/CreditsMessage.java <==
package cn.com.duiba.order.center.api.dto;

import java.io.Serializable;
import java.util.Map;

/**
 * 扣积分消息封装类
 */
public class CreditsMessage implements Serializable {

	/**
	 * 
	 */
	private static final long serialVersionUID = -2892559155424549092L;
	
	public static final String HTTP_GET = "get";
	public static final String HTTP_POST = "post";

	private String relationId;
	private String relationType;
	private String appId;
	private String consumerId;
	private String httpType;
	private String httpUrl;
	private Map<String, String> authParams;
	private Map<String, String> params;
	private Long timestamp;

	public String getRelationId() {
		return relationId;
	}

	public void setRelationId(String relationId) {
		this.relationId = relationId;
	}

	public String getRelationType() {
		return relationType;
	}

	public void setRelationType(String relationType) {
		this.relationType = relationType;
	}

	public String getAppId() {
		return appId;
	}

	public void setAppId(String appId) {
		this.appId = appId;
	}

	public String getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(String consumerId) {
		this.consumerId = consumerId;
	}

	public String getHttpType() {
		return httpType;
	}

	public void setHttpType(String httpType) {
		this.httpType = httpType;
	}

	public String getHttpUrl() {
		return httpUrl;
	}

	public void setHttpUrl(String httpUrl) {
		this.httpUrl = httpUrl;
	}

	public Map<String, String> getParams() {
		return params;
	}

	public void setParams(Map<String, String> params) {
		this.params = params;
	}

	public Map<String, String> getAuthParams() {
		return authParams;
	}

	public void setAuthParams(Map<String, String> authParams) {
		this.authParams = authParams;
	}

	public Long getTimestamp() {
		return timestamp;
	}

	public void setTimestamp(Long timestamp) {
		this.timestamp = timestamp;
	}
	
}
